powered by
A simple dataset for demonstration purposes.
example_sim123
A list containing 3 data frames:
A 1089 x 3 numeric matrix of the true source signals. Each column is an 33 x 33 image.
A 3 x 50 numeric mixing matrix of the true time series. Each row is a time series of corresponding column in smat.
smat
A 1089 x 50 numeric matrix of the simulated data. Each column is the simulated mixed signal at a time point.
data(example_sim123) str(example_sim123)
Run the code above in your browser using DataLab