givens.rotation: For a given angle theta, returns a d x d Givens rotation matrix
Description
For a given angle theta, returns a d x d Givens rotation matrix
Usage
givens.rotation(theta = 0, d = 2, which = c(1, 2))
Arguments
- theta
The value of theta.
- d
The value of d.
- which
The value of which.