The function for perform whitening.
whitener(X, n.comp = ncol(X), center.row = FALSE, use_irlba = TRUE)A list including the whitener matrix, the whitened data matrix, and the mean of the input data.
The data matrix with dimension P x T.
The number of components.
Whether to center the row of data. Default is FALSE.
Whether to use the irlba method to perform fast truncated singular value decomposition in whitening step, helpful for memorying intermediate dataset. Default is TRUE.